/// <reference types="node" />
import { CreateFilter } from 'rollup-pluginutils';
import type { Plugin } from 'rollup';
export interface CSSPluginOptions {
    exclude?: Parameters<CreateFilter>[1];
    failOnError?: boolean;
    /** Literal asset filename, bypasses any hashes in the filename */
    fileName?: string;
    include?: Parameters<CreateFilter>[0];
    includePaths?: string[];
    insert?: boolean;
    /** Asset name, defaults to output.css, Rollup may add a hash to this! Check out RollupConfig.output.assetFileNames */
    name?: string;
    /** @deprecated Use `fileName` instead, currently still available for backwards compatibility */
    output?: string | false | ((css: string, styles: Styles) => void);
    prefix?: string;
    processor?: (css: string, map: string, styles: Styles) => CSS | Promise<CSS> | PostCSSProcessor;
    sass?: SassRenderer;
    sourceMap?: boolean;
    verbose?: boolean;
    watch?: string | string[];
    outputStyle?: string;
}
type CSS = string | {
    css: string;
    map: string;
};
interface MappedCSS {
    css: string;
    map: string;
}
interface Styles {
    [id: string]: string;
}
interface PostCSSProcessor {
    process: (css: string, options?: any) => MappedCSS;
}
interface SassRenderer {
    renderSync: (options: SassOptions) => SassResult;
}
interface SassOptions {
    data: string;
}
interface SassResult {
    css: Buffer;
    map?: Buffer;
}
export default function scss(options?: CSSPluginOptions): Plugin;
export {};
